@@ -930,6 +930,7 @@ static void show_action_options (void)
 {
     const gchar *combo_choice = gtk_combo_box_get_active_id (GTK_COMBO_BOX (ks.new_action_option_widgets[NEW_ACTION_OPTION_COMBO_BOX]));
     const gboolean with_new_item = gtk_widget_get_visible (ks.new_action_option_widgets[INCLUDING_ACTION_CHECK_BUTTON]);
+    const gchar *right_to_left = (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL) ? "&#8207;" : "";
 
     guint8 options_cnt, snotify_opts_cnt;
 
@@ -947,7 +948,8 @@ static void show_action_options (void)
         gtk_widget_show (ks.suboptions_labels[snotify_opts_cnt]);
         gtk_widget_show (ks.suboptions_fields[snotify_opts_cnt]);
     }
-    gtk_label_set_text (GTK_LABEL (ks.options_labels[PROMPT]), " Prompt: ");
+    g_autofree gchar *prompt_label_text = g_strdup_printf  ("%s Prompt: ", right_to_left);
+    gtk_label_set_markup (GTK_LABEL (ks.options_labels[PROMPT]), prompt_label_text);
     if (!with_new_item) {
         gtk_widget_show (ks.new_action_option_widgets[ACTION_OPTION_DONE]);
         gtk_widget_hide (ks.mandatory);
@@ -958,8 +960,11 @@ static void show_action_options (void)
     if (streq_any (combo_choice, "Execute", "Startupnotify", "Enabled", "Name", "WM_CLASS", "Icon", NULL)) {
         for (snotify_opts_cnt = 0; snotify_opts_cnt < NUMBER_OF_STARTUPNOTIFY_OPTS; ++snotify_opts_cnt) {
             g_autofree gchar *suboptions_label_txt = (streq_any (combo_choice, "Execute", "Startupnotify", "Enabled", NULL)) ? 
-                                                     g_strconcat (ks.startupnotify_displayed_txts[snotify_opts_cnt], ": ", NULL) : 
-                                                     g_strdup_printf ("%s (<span foreground='%s'>*</span>): ", 
+                                                     g_strdup_printf ("%s%s: ", 
+                                                                      right_to_left, 
+                                                                      ks.startupnotify_displayed_txts[snotify_opts_cnt]) : 
+                                                     g_strdup_printf ("%s%s (<span foreground='%s'>*</span>): ", 
+                                                                      right_to_left, 
                                                                       ks.startupnotify_displayed_txts[snotify_opts_cnt], 
                                                                       ks.red_hue);
 
@@ -988,11 +993,11 @@ static void show_action_options (void)
     // "Restart" action or "command" option (the latter for "Restart" and "Execute" actions)
     if (streq_any (combo_choice, "Restart", "Command", NULL)) {
         g_autofree gchar *label_txt = (STREQ (combo_choice, "Restart")) ? 
-                                      g_strdup (" Command: ") : 
-                                      g_strdup_printf (" Command (<span foreground='%s'>*</span>): ", ks.red_hue);
+                                      g_strdup_printf ("%s Command: ", right_to_left) : 
+                                      g_strdup_printf ("%s Command (<span foreground='%s'>*</span>): ", right_to_left, ks.red_hue);
 
-        gtk_label_set_markup (GTK_LABEL (ks.options_labels[COMMAND]), label_txt);
         gtk_widget_show (ks.options_labels[COMMAND]);
+        gtk_label_set_markup (GTK_LABEL (ks.options_labels[COMMAND]), label_txt);
         gtk_widget_show (ks.options_fields[COMMAND]);
         if (STREQ (combo_choice, "Command")) { 
             gtk_widget_show (ks.mandatory);
@@ -1005,7 +1010,7 @@ static void show_action_options (void)
     if (streq_any (combo_choice, "Exit", "Prompt", "SessionLogout", NULL)) {
          if (!STREQ (combo_choice, "Prompt") || 
             (STREQ (combo_choice, "Prompt") && streq_any (ks.txt_fields[MENU_ELEMENT_TXT], "Exit", "SessionLogout", NULL))) {
-            gtk_label_set_text (GTK_LABEL (ks.options_labels[SN_OR_PROMPT]), " Prompt: ");
+            gtk_label_set_markup (GTK_LABEL (ks.options_labels[SN_OR_PROMPT]), prompt_label_text);
             gtk_widget_show (ks.options_labels[SN_OR_PROMPT]);
             if (g_signal_handler_is_connected (ks.options_fields[SN_OR_PROMPT], ks.handler_id_show_or_hide_startupnotify_options)) {
                 g_signal_handler_disconnect (ks.options_fields[SN_OR_PROMPT], ks.handler_id_show_or_hide_startupnotify_options);
@@ -1015,13 +1020,12 @@ static void show_action_options (void)
             gtk_widget_grab_focus (ks.options_fields[SN_OR_PROMPT]);
         }
         else { // Option of "Execute" action.
-            g_autofree gchar *prompt_label_txt = g_strdup_printf (" Prompt (<span foreground='%s'>*</span>): ", ks.red_hue);
+            g_autofree gchar *prompt_label_txt = g_strdup_printf ("%s Prompt (<span foreground='%s'>*</span>): ", right_to_left, ks.red_hue);
 
             gtk_widget_show (ks.options_labels[PROMPT]);
             gtk_label_set_markup (GTK_LABEL (ks.options_labels[PROMPT]), prompt_label_txt);
             gtk_widget_show (ks.options_fields[PROMPT]);
             gtk_widget_show (ks.mandatory);
-
         }
     }
 
